# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["ActionTools"]

ActionTools: TypeAlias = Literal["calendar", "schedule_recurring_message_tool"]
