# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["EnhancedResponsesTools"]

EnhancedResponsesTools: TypeAlias = Literal["connect_data", "create_dataset", "download_data"]
