# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["WebTools"]

WebTools: TypeAlias = Literal["company_prospect_researcher", "people_prospect_researcher", "web_search", "fetch_url"]
