# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["KnowledgeManagementTools"]

KnowledgeManagementTools: TypeAlias = Literal[
    "data_analysis", "image_detection", "agent_memory", "pdf_extraction", "semantic_search_tool"
]
