# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["DataProcessingTools"]

DataProcessingTools: TypeAlias = Literal["data_classification", "data_extraction", "schema_info", "table_info"]
